const inquirer = require("inquirer");

const userConfig = require("../config/user.config");
const { init, articleGroup } = require("./visit");
const colors = require("colors");

const inquirerParams = {
  articleUrl: {
    type: "input",
    message: "请输入文章地址(多篇以英文','分割)：",
    name: "articleUrl",
    validate(val) {
      const chineseRegEx = /[\u4e00-\u9fa5]/g;
      const csdnRegEx =
        /^https:\/\/blog\.csdn\.net\/.{3,}\/article\/details\/(.{5,})/;
      if (!val) return "链接不能为空!";
      if (chineseRegEx.test(val)) return "路径中不能包含中文!";
      if (!csdnRegEx.test(val)) return "请输入正确的CSDN链接!";
      return true;
    },
  },
  userID: {
    type: "input",
    message: "请输入你的CSDN用户ID",
    name: "userID",
    suffix: "(个人中心=>个人资料=>用户ID):",
    validate(val) {
      if (!val) return "请输入用户ID";
      return true;
    },
  },
  auth: {
    type: "password", // 密码为密文输入
    message: "请输入你的授权码:",
    name: "auth",
    validate(val) {
      if (!val) return "请输入授权码";
      return true;
    },
  },
  mode: {
    type: "rawlist",
    message: "请选择访问方式:",
    name: "mode",
    choices: [
      "随机访问全部",
      "前n条",
      "后n条",
      "随机访问n条",
      "从开始到结尾",
      "从结尾到开始",
    ],
    pageSize: 10, // 设置行数
  },
  pv: {
    type: "rawlist",
    message: "请选择单篇PV(访问量):",
    name: "pv",
    choices: ["9", "99", "999", "9999", "99999", "9999999", "Infinity"],
    pageSize: 10, // 设置行数
  },
  speed: {
    type: "rawlist",
    message: "请选择速度(ms/step):",
    name: "speed",
    choices: ["200", "500", "1000", "2000", "3000", "5000", "10000"],
    pageSize: 10, // 设置行数
  },
  inputN: {
    type: "input",
    message: "请输入要访问的数量:",
    name: "inputN",
    validate(val) {
      if (!val) return "请输入访问数量";
      const numberReg = /^[0-9]*$/;
      if (!numberReg.test(val)) return "只能输入数字";
      return true;
    },
  },
};

/**
 * 启动程序
 */
const start = async () => {
  const config = {};
  if (!userConfig.userID) {
    // 请输入你的CSDN用户ID
    let userIdInfo = await inquirer.prompt(inquirerParams.userID);
    config.userID = userIdInfo.userID;
  }

  // 1.请输入你的授权码
  let authInfo = await inquirer.prompt(inquirerParams.auth);
  if (authInfo.auth.toUpperCase() != "AK47") {
    console.warn(
      "---------------------This Authorization Error---------------------".red
    );
    process.exit(1);
  }
  config.auth = authInfo.auth;

  // 2.请选择访问方式
  let modeInfo = await inquirer.prompt(inquirerParams.mode);
  if (modeInfo.mode == "随机访问n条") {
    let selectModeInfo = await inquirer.prompt(inquirerParams.inputN);
    config.mode = {
      type: "random",
      n: selectModeInfo.inputN,
    };
  } else if (modeInfo.mode == "前n条") {
    let selectModeInfo = await inquirer.prompt(inquirerParams.inputN);
    config.mode = {
      type: "first",
      n: selectModeInfo.inputN,
    };
  } else if (modeInfo.mode == "后n条") {
    let selectModeInfo = await inquirer.prompt(inquirerParams.inputN);
    config.mode = {
      type: "last",
      n: selectModeInfo.inputN,
    };
  } else {
    config.mode = {
      type: "all",
    };
  }

  // 3.请选择单篇PV(访问量)
  // let pvInfo = await inquirer.prompt(inquirerParams.pv)
  // config.pv = pvInfo.pv

  // 4.请选择速度(ms/step)
  let speedInfo = await inquirer.prompt(inquirerParams.speed);
  config.speed = speedInfo.speed;

  init(config);
};

const single = async () => {
  // 请输入文章地址
  let userObj = await inquirer.prompt(inquirerParams.articleUrl);
  const articleUrlArr = userObj.articleUrl.split(",");
  // 开始访问
  articleGroup(articleUrlArr);
};
module.exports = {
  start,
  single,
};
